require 'acceptance_helpers'

resource 'Learning Objects' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  before { 12.times { create(:learning_object) } }

  let(:learning_objects) { LearningObject.all }

  get '/v1/learning_objects' do
    parameter :limit, 'Limit of learning objects'
    parameter :offset, 'Offset of learning objects'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of learning objects' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(LearningObject.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  get '/v1/learning_objects/:id' do
    let(:id) { learning_objects.first.id }

    example 'Get a learning object' do
      do_request
      expect(path).to eq("/v1/learning_objects/#{id}") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(LearningObject.find(id)))
      expect(status).to eq(200)
    end
  end

end
